Aglyph 2.1.1 testing summary — Aglyph 3.0.0 documentation

# Aglyph 2.1.1 testing summary

Warning

Changed in version 2.1.1.

The Python 3.2 lifespan has ended; the Aglyph test suite is no longer executed under this version.

Note

Prior to each Aglyph release being committed, tagged, and packaged, its test suite is executed on several Python implementations, versions, and platforms.

When a Python version reaches end-of-life, the Aglyph test suite is no longer “officially” executed against that version. This does not necessarily imply that Aglyph unit tests fail under that Python version; it simply means that I no longer publish or withhold a release based on the test suite results from that particular Python version.

## CPython

Version | Platform
--- | ---
2.7.12 | [GCC 4.2.1 Compatible Apple LLVM 7.0.2 (clang-700.1.81)] on Darwin-15.6.0-x86_64-i386-64bit
| [GCC 6.1.1 20160621 (Red Hat 6.1.1-3)] on Linux-4.6.5-300.fc24.x86_64-x86_64-with-fedora-24-Twenty_Four
2.7.11 | Windows-7-6.1.7601-SP1 MSC v.1500 32 bit (Intel)
3.3.6 | [GCC 4.2.1 Compatible Apple LLVM 7.0.2 (clang-700.1.81)] on Darwin-15.6.0-x86_64-i386-64bit
3.3.5 | Windows-7-6.1.7601-SP1 MSC v.1600 32 bit (Intel)
3.4.5 | [GCC 4.2.1 Compatible Apple LLVM 7.0.2 (clang-700.1.81)] on Darwin-15.6.0-x86_64-i386-64bit
3.4.4 | Windows-7-6.1.7601-SP1 MSC v.1600 32 bit (Intel)
3.5.2 | [GCC 4.2.1 Compatible Apple LLVM 7.0.2 (clang-700.1.81)] on Darwin-15.6.0-x86_64-i386-64bit
3.5.1 | Windows-7-6.1.7601-SP1 MSC v.1900 32 bit (Intel)
| [GCC 6.1.1 20160621 (Red Hat 6.1.1-3)] on Linux-4.6.5-300.fc24.x86_64-x86_64-with-fedora-24-Twenty_Four

## PyPy

Version | Platform
--- | ---
5.3.1 | (CPython 2.7.10) [GCC 4.2.1 Compatible Apple LLVM 7.0.2 (clang-700.1.81)] on Darwin-15.6.0-x86_64-i386-64bit
2.6.0 | (CPython 2.7.9) Windows-7-6.1.7601-SP1
2.4.0 | (CPython 3.2.5) Windows-7-6.1.7601-SP1

## Stackless Python

Version | Platform
--- | ---
3.1b3 | (CPython 2.7.9) [GCC 4.2.1 Compatible Apple LLVM 7.0.2 (clang-700.1.81)] on Darwin-15.6.0-x86_64-i386-64bit
| (CPython 3.3.6) [GCC 4.2.1 Compatible Apple LLVM 7.0.2 (clang-700.1.81)] on Darwin-15.6.0-x86_64-i386-64bit
| (CPython 3.4.2) [GCC 4.2.1 Compatible Apple LLVM 7.0.2 (clang-700.1.81)] on Darwin-15.6.0-x86_64-i386-64bit

## IronPython

Version | Platform
--- | ---
2.7.5 | cli-32bit .NET 4.0.30319.42000 (32-bit) on Windows-7-6.1.7601-SP1

## Jython

Version | Platform
--- | ---
2.7.0 | Java-1.8.0_51-Java_HotSpot-TM-_64-Bit_Server_VM,_25.51-b03,_Oracle_Corporation-on-Mac_OS_X-10.11.6-x86_64
| Java-1.8.0_51-Java_HotSpot-TM-_Client_VM,_25.51-b03,_Oracle_Corporation-on-Windows_7-6.1-x86